@@ -2,6 +2,7 @@ import sys
 import re
 import subprocess
 import contextlib
+import tempfile
 
 import pip_run
 import tempora
@@ -73,28 +74,29 @@ class BenchmarkRunner:
     Result('...', '...')
     """
 
-    def __init__(self, extras=(), deps=()):
+    def __init__(self, extras=(), deps=(), control=None):
         spec = f'[{",".join(extras)}]' if extras else ''
         self.stack = contextlib.ExitStack()
-        self.baseline_env = self._setup_env(upstream_url(spec), *deps)
-        self.local_env = self._setup_env(f'.{spec}', *deps)
+        self.control_env = self._setup_env(upstream_url(spec, control), *deps)
+        self.experiment_env = self._setup_env(f'.{spec}', *deps)
 
     def _setup_env(self, *deps):
         target = self.stack.enter_context(pip_run.deps.load(*deps))
         return pip_run.launch._setup_env(target)
 
     def run(self, cmd: Command):
-        local = self.eval(cmd, env=self.local_env)
-        benchmark = self.eval(cmd, env=self.baseline_env)
-        return Result(benchmark, local)
+        experiment = self.eval(cmd, env=self.experiment_env)
+        control = self.eval(cmd, env=self.control_env)
+        return Result(control, experiment)
 
     def eval(self, cmd, **kwargs):
-        out = subprocess.check_output(cmd, **_text, **kwargs)
+        with tempfile.TemporaryDirectory() as empty:
+            out = subprocess.check_output(cmd, cwd=empty, **_text, **kwargs)
         val = re.search(r'([0-9.]+ \w+) per loop', out).group(1)
         return val
 
 
-def upstream_url(extras=''):
+def upstream_url(extras='', control=None):
     """
     >>> upstream_url()
     'pytest-perf@git+https://github.com/jaraco/pytest-perf'
@@ -102,4 +104,5 @@ def upstream_url(extras=''):
     cmd = ['git', 'remote', 'get-url', 'origin']
     origin = subprocess.check_output(cmd, **_text).strip()
     base, sep, name = origin.rpartition('/')
-    return f'{name}{extras}@git+{origin}'
+    rev = f'@{control}' if control else ''
+    return f'{name}{extras}@git+{origin}{rev}'
